@@ -6,6 +6,7 @@ var group__cpp__entities =
       [ "entity", "structflecs_1_1entity.html#a5507fae8c3f326e957f468372b63b322", null ],
       [ "entity", "structflecs_1_1entity.html#ac343dbb0c6a3cd44bd97863127a1c2a0", null ],
       [ "entity", "structflecs_1_1entity.html#a9d2361efe2ea358b3bd0728408ced507", null ],
+      [ "child", "structflecs_1_1entity.html#af6ff23d1598489b6213284a29dcd2a9a", null ],
       [ "clear", "structflecs_1_1entity.html#a3a115a6cbd08c6de08e0ecfe8608ccbb", null ],
       [ "destruct", "structflecs_1_1entity.html#a05c1af95015764fc68aa790d274f4462", null ],
       [ "ensure", "structflecs_1_1entity.html#a8fca9021f1846e165eba581adaee64ba", null ],
@@ -24,6 +25,7 @@ var group__cpp__entities =
       [ "modified", "structflecs_1_1entity.html#a34ed2767da35c164134b21f4d4a083b4", null ],
       [ "modified", "structflecs_1_1entity.html#a46b645e7cdfe073077b392231e231f10", null ],
       [ "modified", "structflecs_1_1entity.html#a0e494b2a380e94acb8a15e10eb031170", null ],
+      [ "set_child_order", "structflecs_1_1entity.html#ad552d436290984e56b5327afc33c3833", null ],
       [ "view", "structflecs_1_1entity.html#acc0abe24401b9c3fb54187258a7edb64", null ]
     ] ],
     [ "flecs::entity_view", "structflecs_1_1entity__view.html", [
@@ -73,26 +75,26 @@ var group__cpp__entities =
       [ "enqueue", "structflecs_1_1entity__view.html#a4ebd53ad482c45706a99273a75646eb5", null ],
       [ "enqueue", "structflecs_1_1entity__view.html#a6e4fb24de96dae91124d0c1b3ad0ab33", null ],
       [ "enqueue", "structflecs_1_1entity__view.html#a6e4fb24de96dae91124d0c1b3ad0ab33", null ],
-      [ "get", "structflecs_1_1entity__view.html#a0346ee1d253320de7e04e5b0c81ec5ee", null ],
-      [ "get", "structflecs_1_1entity__view.html#a5a63e8170c5e40a2de18c06ac3ec739a", null ],
-      [ "get", "structflecs_1_1entity__view.html#a9f8675b85821673f945089e066d1c7e1", null ],
-      [ "get", "structflecs_1_1entity__view.html#a0346ee1d253320de7e04e5b0c81ec5ee", null ],
+      [ "get", "structflecs_1_1entity__view.html#a3d3a6d9a9008c2bcf94d11c53731be0f", null ],
+      [ "get", "structflecs_1_1entity__view.html#ac0179e060eda565b0bb31f6ce8796b7e", null ],
+      [ "get", "structflecs_1_1entity__view.html#aa6a01467b2411f9bec7d779740a8d372", null ],
       [ "get", "structflecs_1_1entity__view.html#ae49ff16148128ab73dba9360c45ae16a", null ],
       [ "get", "structflecs_1_1entity__view.html#aa31137457d97c65750a9d1ab1cab9ef1", null ],
       [ "get", "structflecs_1_1entity__view.html#add3902e51c4eb488c2730707bf7ff291", null ],
-      [ "get", "structflecs_1_1entity__view.html#a8d9b8486dba7a208cebb3a5c4da5f206", null ],
-      [ "get", "structflecs_1_1entity__view.html#a1d2cb6be6739a4410c5d62e8a9ddef65", null ],
-      [ "get_mut", "structflecs_1_1entity__view.html#a740c3dfe2a6c29bf30a985701cf8b602", null ],
-      [ "get_mut", "structflecs_1_1entity__view.html#a0301ee71d834d1f19f3b330bf2b72cf9", null ],
-      [ "get_mut", "structflecs_1_1entity__view.html#af4fa79182de03d7c422fe4d85e00c48a", null ],
+      [ "get", "structflecs_1_1entity__view.html#a6d8ffc799cac931f295eab7606cac54f", null ],
+      [ "get", "structflecs_1_1entity__view.html#a63582be552a61044c514534eaf82eb97", null ],
+      [ "get_constant", "structflecs_1_1entity__view.html#ac393176143b64ce79aed580fd987e721", null ],
+      [ "get_mut", "structflecs_1_1entity__view.html#a1c009cbdd24cd4ec187ae7398065aa1b", null ],
+      [ "get_mut", "structflecs_1_1entity__view.html#a1c064c250b00ff7498024c73ddcf3b43", null ],
+      [ "get_mut", "structflecs_1_1entity__view.html#a2dba3c2f253d789794ac82e5eb7848c3", null ],
       [ "get_mut", "structflecs_1_1entity__view.html#a370ce1f8aafbed1f1d3e54a23cb3275e", null ],
       [ "get_mut", "structflecs_1_1entity__view.html#a9b0e66fe4276d2fbe5337df5bf853fb9", null ],
-      [ "get_mut", "structflecs_1_1entity__view.html#aab016dc7f1fe6a64749ac9ed03345241", null ],
-      [ "get_mut", "structflecs_1_1entity__view.html#abccc38d024d97444b36e8afa36bfd67d", null ],
+      [ "get_mut", "structflecs_1_1entity__view.html#a1afb751d27bc9ca4de094143bf4a58f7", null ],
+      [ "get_mut", "structflecs_1_1entity__view.html#ac8e77d357e7322d698b25a7686f2c417", null ],
       [ "get_mut_second", "structflecs_1_1entity__view.html#a7b55d3c499a08d921c34495b1aad9461", null ],
-      [ "get_mut_second", "structflecs_1_1entity__view.html#acf4bb645f4eabfc3f135be1e77fa4bab", null ],
-      [ "get_second", "structflecs_1_1entity__view.html#a24b2922836a2c4137f24e7b4f00d59c7", null ],
-      [ "get_second", "structflecs_1_1entity__view.html#a23f5b0c041f7114f841625f83e03c311", null ],
+      [ "get_mut_second", "structflecs_1_1entity__view.html#a6d241b0a822af13be853bbcdc0b33794", null ],
+      [ "get_second", "structflecs_1_1entity__view.html#a3b499d598d51a0f28ae9d8adc24507d5", null ],
+      [ "get_second", "structflecs_1_1entity__view.html#a3b3acc9198bb7c9adab1aa38549f8b4d", null ],
       [ "has", "structflecs_1_1entity__view.html#ab112fabea4a346faa70c6ab6893f32c5", null ],
       [ "has", "structflecs_1_1entity__view.html#ade76deb5597ef77c19a4f3f0e139a243", null ],
       [ "has", "structflecs_1_1entity__view.html#afd306a2dc2fce9b7ffc64c0281183944", null ],
@@ -128,6 +130,24 @@ var group__cpp__entities =
       [ "to_constant", "group__cpp__entities.html#ga58a06a1f245b3b96165092ca16737df1", null ],
       [ "to_json", "structflecs_1_1entity__view.html#ga30ca7153aeaa3eb012f44d8aa3374e89", null ],
       [ "to_json", "group__cpp__addons__json.html#ga30ca7153aeaa3eb012f44d8aa3374e89", null ],
+      [ "try_get", "structflecs_1_1entity__view.html#adbdc382040cceb53ce535e300cdc43c3", null ],
+      [ "try_get", "structflecs_1_1entity__view.html#affc0e8aa3a6c7e3335e96b2ce61c4112", null ],
+      [ "try_get", "structflecs_1_1entity__view.html#a233d3c98a7a2b47261f2e46b70c2f328", null ],
+      [ "try_get", "structflecs_1_1entity__view.html#a2a07ba0a74481ca70319e9bcabfcfd38", null ],
+      [ "try_get", "structflecs_1_1entity__view.html#a66769cabaea72a9a31fb84af50a5710a", null ],
+      [ "try_get", "structflecs_1_1entity__view.html#a5a6f839ba7fb59db40610d0e9799ab9e", null ],
+      [ "try_get", "structflecs_1_1entity__view.html#a9846aac03aa60f5e3f87a5b1fc15b822", null ],
+      [ "try_get_mut", "structflecs_1_1entity__view.html#ab5156fc60999b1f4318ae812e3b2fc5d", null ],
+      [ "try_get_mut", "structflecs_1_1entity__view.html#a8491e2355033d76b6582f9b5d5c64093", null ],
+      [ "try_get_mut", "structflecs_1_1entity__view.html#a9d6cd8aa1149d3cb16cf2214896b607a", null ],
+      [ "try_get_mut", "structflecs_1_1entity__view.html#ace280816c70408c6cad613180d4e9ba7", null ],
+      [ "try_get_mut", "structflecs_1_1entity__view.html#abd21775b44d51d95297a180016d1e2a4", null ],
+      [ "try_get_mut", "structflecs_1_1entity__view.html#ae134b1cc36064c84a4db5b525f5e0e31", null ],
+      [ "try_get_mut", "structflecs_1_1entity__view.html#ad35c298e174187789d09f04d1ea73d50", null ],
+      [ "try_get_mut_second", "structflecs_1_1entity__view.html#acb870e431ba8de0a291609b9f8848d65", null ],
+      [ "try_get_mut_second", "structflecs_1_1entity__view.html#a5ed6622a1f94d3bf57636971bf26d159", null ],
+      [ "try_get_second", "structflecs_1_1entity__view.html#aecd4f73209a122ad59b92390c78fa770", null ],
+      [ "try_get_second", "structflecs_1_1entity__view.html#a16862338008914173decdc3ef9e4a1f1", null ],
       [ "type", "structflecs_1_1entity__view.html#a02733f595103809e82ac3b1119ec7645", null ],
       [ "unit", "group__cpp__addons__meta.html#ga2bc94f1781c3f53ee9191cf26da588ae", null ],
       [ "quantity", "group__cpp__addons__meta.html#gac86161629bc421f597655579e8694b04", null ],
@@ -151,6 +171,17 @@ var group__cpp__entities =
       [ "add_if", "structflecs_1_1entity__builder.html#a9d651da4c0157c71e8e9bddf766bc34c", null ],
       [ "add_if", "structflecs_1_1entity__builder.html#a9ff2735c8ba886c032335be708315e96", null ],
       [ "add_second", "structflecs_1_1entity__builder.html#a9fc35623fba54ecc3a5a73cddc7b58d7", null ],
+      [ "assign", "structflecs_1_1entity__builder.html#ab44c3bced7ca83b257ec5ddb2f9333de", null ],
+      [ "assign", "structflecs_1_1entity__builder.html#a69d3b33488eac33d4ff91078b663394b", null ],
+      [ "assign", "structflecs_1_1entity__builder.html#a28a4b39e70cd115196b5daafcb04ce20", null ],
+      [ "assign", "structflecs_1_1entity__builder.html#a63f0abc060edce31fad865da12c772e5", null ],
+      [ "assign", "structflecs_1_1entity__builder.html#a6cc427851ba7ce3c59ceda468f989bd5", null ],
+      [ "assign", "structflecs_1_1entity__builder.html#ab8899ffde3b71d521d2b855fe8cbc283", null ],
+      [ "assign", "structflecs_1_1entity__builder.html#a99d917441f96f26da3059996d94b9f4f", null ],
+      [ "assign", "structflecs_1_1entity__builder.html#a3334988303481b0b78a878d92ed55c6b", null ],
+      [ "assign", "structflecs_1_1entity__builder.html#a6f9f13eb014ece6c3e72b0bd83290a73", null ],
+      [ "assign_second", "structflecs_1_1entity__builder.html#af0b40c5ee7a8a189b464fabe6bc627d7", null ],
+      [ "assign_second", "structflecs_1_1entity__builder.html#a9df105c5f9b016690e92b391e0f65ad8", null ],
       [ "auto_override", "structflecs_1_1entity__builder.html#a45b772f4c004019272c35a5df3994106", null ],
       [ "auto_override", "structflecs_1_1entity__builder.html#ae855dda8007cee2d318be9ea6e808edf", null ],
       [ "auto_override", "structflecs_1_1entity__builder.html#ae83a78c02936ea236552bb1a92e99157", null ],
@@ -196,11 +227,15 @@ var group__cpp__entities =
       [ "remove_second", "structflecs_1_1entity__builder.html#a404a701f159da50aa62c1104f8898423", null ],
       [ "scope", "structflecs_1_1entity__builder.html#a47a86bfaacdfba0fe44e7c5188a8d449", null ],
       [ "scope", "structflecs_1_1entity__builder.html#a9a98eb882db1004e8ef0ea4d04191d21", null ],
+      [ "set", "structflecs_1_1entity__builder.html#abfe84f9ebd5f9ae23cd2e27682d7f10b", null ],
       [ "set", "structflecs_1_1entity__builder.html#a5344856be84e6fe5a638a896050d4b93", null ],
+      [ "set", "structflecs_1_1entity__builder.html#a584c17375f7820fc678aac1e1acb6be9", null ],
       [ "set", "structflecs_1_1entity__builder.html#adcdd091aade64facfcfa2a45a34062c8", null ],
+      [ "set", "structflecs_1_1entity__builder.html#a4898eb0f60a52a0bf2336025d61d9443", null ],
       [ "set", "structflecs_1_1entity__builder.html#a146289ece6a533e68b6a3a38d991099d", null ],
       [ "set", "structflecs_1_1entity__builder.html#a6dd543de232e2d9dcc7fab90c104f071", null ],
       [ "set", "structflecs_1_1entity__builder.html#a99a05333374dba34c0aa2fe9843d366f", null ],
+      [ "set", "structflecs_1_1entity__builder.html#ac7a1b354c1f13c01e9898b012d2b34e8", null ],
       [ "set_auto_override", "structflecs_1_1entity__builder.html#a554515e6ae5dca1231c1627f0752512b", null ],
       [ "set_auto_override", "structflecs_1_1entity__builder.html#af6dd73f75e5483ad378c20f593210037", null ],
       [ "set_auto_override", "structflecs_1_1entity__builder.html#ab11f0e9f816e72133e48eaec63c7ae67", null ],
@@ -231,6 +266,7 @@ var group__cpp__entities =
       [ "set_json", "group__cpp__addons__json.html#gad6b8a4ab52df0cfbff91cf1a96896218", null ],
       [ "set_json_second", "structflecs_1_1entity__builder.html#ga4c4de9b34edbf7fb3ef8dd1e56601a8c", null ],
       [ "set_json_second", "group__cpp__addons__json.html#ga4c4de9b34edbf7fb3ef8dd1e56601a8c", null ],
+      [ "set_second", "structflecs_1_1entity__builder.html#aafededaae12672400a80760e75e937c3", null ],
       [ "set_second", "structflecs_1_1entity__builder.html#afed8c2ec34f0701611596c6d5ca2ff98", null ],
       [ "set_second", "structflecs_1_1entity__builder.html#a81e94bad637236db20f21608ef7613ed", null ],
       [ "slot", "structflecs_1_1entity__builder.html#a5ed232a47807a146194bcc2873d95100", null ],
