@@ -3,8 +3,8 @@ var namespaces_dup =
     [ "flecs", null, [
       [ "_", "namespaceflecs_1_1__.html", "namespaceflecs_1_1__" ],
       [ "actual_type", "structflecs_1_1actual__type.html", null ],
-      [ "actual_type< T, if_not_t< is_pair< T >::value > >", "structflecs_1_1actual__type.html", null ],
-      [ "actual_type< T, if_t< is_pair< T >::value > >", "structflecs_1_1actual__type.html", null ],
+      [ "actual_type< T, if_not_t< is_pair< T >::value > >", "structflecs_1_1actual__type_3_01T_00_01if__not__t_3_01is__pair_3_01T_01_4_1_1value_01_4_01_4.html", null ],
+      [ "actual_type< T, if_t< is_pair< T >::value > >", "structflecs_1_1actual__type_3_01T_00_01if__t_3_01is__pair_3_01T_01_4_1_1value_01_4_01_4.html", null ],
       [ "alert", "structflecs_1_1alert.html", "structflecs_1_1alert" ],
       [ "alert_builder", "structflecs_1_1alert__builder.html", null ],
       [ "alert_builder_i", "structflecs_1_1alert__builder__i.html", "structflecs_1_1alert__builder__i" ],
@@ -12,8 +12,8 @@ var namespaces_dup =
       [ "app_builder", "structflecs_1_1app__builder.html", null ],
       [ "arity", "structflecs_1_1arity.html", null ],
       [ "array", "structflecs_1_1array.html", null ],
-      [ "array< T, Size, enable_if_t< Size !=0 > >", "structflecs_1_1array.html", null ],
-      [ "array< T, Size, enable_if_t< Size==0 > >", "structflecs_1_1array.html", null ],
+      [ "array< T, Size, enable_if_t< Size !=0 > >", "structflecs_1_1array_3_01T_00_01Size_00_01enable__if__t_3_01Size_01_9_0a0_01_4_01_4.html", null ],
+      [ "array< T, Size, enable_if_t< Size==0 > >", "structflecs_1_1array_3_01T_00_01Size_00_01enable__if__t_3_01Size_0a_0a0_01_4_01_4.html", null ],
       [ "array_iterator", "structflecs_1_1array__iterator.html", null ],
       [ "base_arg_type", "structflecs_1_1base__arg__type.html", null ],
       [ "base_type", "structflecs_1_1base__type.html", null ],
@@ -31,12 +31,13 @@ var namespaces_dup =
       [ "field", "structflecs_1_1field.html", "structflecs_1_1field" ],
       [ "first_arg", "structflecs_1_1first__arg.html", null ],
       [ "first_arg_impl", "structflecs_1_1first__arg__impl.html", null ],
-      [ "first_arg_impl< Func, _::arg_list< T, Args ... > >", "structflecs_1_1first__arg__impl.html", null ],
+      [ "first_arg_impl< Func, _::arg_list< T, Args ... > >", "structflecs_1_1first__arg__impl_3_01Func_00_01___1_1arg__list_3_01T_00_01Args_01_8_8_8_01_4_01_4.html", null ],
       [ "id", "structflecs_1_1id.html", "structflecs_1_1id" ],
       [ "is_actual", "structflecs_1_1is__actual.html", null ],
       [ "is_callable", "structflecs_1_1is__callable.html", null ],
       [ "is_flecs_constructible", "structflecs_1_1is__flecs__constructible.html", null ],
       [ "is_pair", "structflecs_1_1is__pair.html", null ],
+      [ "is_same", "classflecs_1_1is__same.html", null ],
       [ "iter", "structflecs_1_1iter.html", "structflecs_1_1iter" ],
       [ "iter_iterable", "structflecs_1_1iter__iterable.html", "structflecs_1_1iter__iterable" ],
       [ "iterable", "structflecs_1_1iterable.html", "structflecs_1_1iterable" ],
@@ -55,12 +56,12 @@ var namespaces_dup =
       [ "query_base", "structflecs_1_1query__base.html", "structflecs_1_1query__base" ],
       [ "query_builder", "structflecs_1_1query__builder.html", null ],
       [ "query_builder_i", "structflecs_1_1query__builder__i.html", "structflecs_1_1query__builder__i" ],
-      [ "ref", "structflecs_1_1ref.html", "structflecs_1_1ref" ],
+      [ "ref", "structflecs_1_1ref.html", null ],
       [ "scoped_world", "structflecs_1_1scoped__world.html", null ],
       [ "script_builder", "structflecs_1_1script__builder.html", null ],
       [ "second_arg", "structflecs_1_1second__arg.html", null ],
       [ "second_arg_impl", "structflecs_1_1second__arg__impl.html", null ],
-      [ "second_arg_impl< Func, _::arg_list< First, T, Args ... > >", "structflecs_1_1second__arg__impl.html", null ],
+      [ "second_arg_impl< Func, _::arg_list< First, T, Args ... > >", "structflecs_1_1second__arg__impl_3_01Func_00_01___1_1arg__list_3_01First_00_01T_00_01Args_01_8_8_8_01_4_01_4.html", null ],
       [ "stats", "structflecs_1_1stats.html", null ],
       [ "string", "structflecs_1_1string.html", null ],
       [ "string_view", "structflecs_1_1string__view.html", null ],
@@ -79,6 +80,7 @@ var namespaces_dup =
       [ "units", "structflecs_1_1units.html", null ],
       [ "untyped_component", "structflecs_1_1untyped__component.html", "structflecs_1_1untyped__component" ],
       [ "untyped_field", "structflecs_1_1untyped__field.html", "structflecs_1_1untyped__field" ],
+      [ "untyped_ref", "structflecs_1_1untyped__ref.html", "structflecs_1_1untyped__ref" ],
       [ "worker_iterable", "structflecs_1_1worker__iterable.html", null ],
       [ "world", "structflecs_1_1world.html", "structflecs_1_1world" ],
       [ "pair_first_t", "group__cpp__pair__type.html#gafbe761180d0c10d50a1ddb50f6f66eeb", null ],
@@ -86,6 +88,8 @@ var namespaces_dup =
       [ "pair_type_t", "group__cpp__pair__type.html#ga301d90dff367ff0b7974bb189b7ea1b7", null ],
       [ "PipelineStats", "group__cpp__addons__stats.html#ga9fc70b88cfdeb2da1821fd783eadb57f", null ],
       [ "serialize", "group__cpp__addons__meta.html#ga987426ea7bc2a0aee1850f77c2512888", null ],
+      [ "serialize_element", "group__cpp__addons__meta.html#ga3dc1316ac22c97276ffac7060bda16c0", null ],
+      [ "serialize_member", "group__cpp__addons__meta.html#gaabc6d5e90f896b1e5f18293a65696fe2", null ],
       [ "serialize_t", "group__cpp__addons__meta.html#gacd2ebeff1d616dd3fe4da8cf655d0ee3", null ],
       [ "serializer", "group__cpp__addons__meta.html#ga35bfe812608b4c02dd1058e71834c974", null ],
       [ "WorldStats", "group__cpp__addons__stats.html#gabb3f9a804e3a4ec5ea1f4ccf48a1f850", null ],
@@ -96,10 +100,10 @@ var namespaces_dup =
       [ "array", "group__cpp__addons__meta.html#ga83a26164619fc68d6c5facd8b6da2671", null ],
       [ "array", "structflecs_1_1world.html#a290dbe18df4d2739f6e3412470f7e421", null ],
       [ "array", "structflecs_1_1world.html#a54a7c8f1b846be215f0fc2d86298603e", null ],
-      [ "bit", "group__cpp__addons__meta.html#gaf0f195a58a7d935aabbf5848aeaaeaf4", null ],
+      [ "bit", "group__cpp__addons__meta.html#gab0eec710bc70c33fb74f4285a568a9f9", null ],
       [ "component", "structflecs_1_1world.html#gae215acdf24d5c8edcfc56c2c003e58f2", null ],
       [ "component", "structflecs_1_1world.html#gadf19fec48c5a4b372b9858eb5e1b6bd3", null ],
-      [ "constant", "group__cpp__addons__meta.html#ga232842b5b739911a9124334f8e70981c", null ],
+      [ "constant", "group__cpp__addons__meta.html#ga69e3ff4b179e3b0b464a9f9d72efa772", null ],
       [ "cursor", "structflecs_1_1world.html#ga7801bddc835d400dc71c6261f64fba2b", null ],
       [ "cursor", "structflecs_1_1world.html#af14e2f21de0df9ac42c914b5bf942b8b", null ],
       [ "doc_brief", "structflecs_1_1entity__view.html#gabf672e81afeddec4a4e2c0f8250ff021", null ],
@@ -217,9 +221,9 @@ var namespaces_dup =
       [ "to_json", "structflecs_1_1entity__view.html#ga30ca7153aeaa3eb012f44d8aa3374e89", null ],
       [ "to_json", "group__cpp__addons__json.html#ga6409d9ef8b8dd7b365ae41b3a96b416c", null ],
       [ "to_json", "structflecs_1_1query__base.html#ga6409d9ef8b8dd7b365ae41b3a96b416c", null ],
-      [ "to_json", "structflecs_1_1world.html#ga8c878935cdb8bb7740054bb6dd97ed0d", null ],
-      [ "to_json", "structflecs_1_1world.html#ga87909bb5dff358a28bb27a6f664010a7", null ],
-      [ "to_json", "structflecs_1_1world.html#gac150ac618ee74c75d3ae31f89dc06565", null ],
+      [ "to_json", "structflecs_1_1world.html#gae2dafcc1231b5f0015e0b991e40c48a8", null ],
+      [ "to_json", "structflecs_1_1world.html#ga942011b9de4fcaee6adca58425a21691", null ],
+      [ "to_json", "structflecs_1_1world.html#gafe54e0baa3164c35dbc20cabaee28aad", null ],
       [ "unit", "group__cpp__addons__meta.html#ga2bc94f1781c3f53ee9191cf26da588ae", null ],
       [ "unit", "group__cpp__addons__meta.html#ga5876427fe4e3cd6077cd03819d7758e7", null ],
       [ "unit_prefix", "group__cpp__addons__meta.html#ga72b3a9713d33456ff9ee3964f1122ec9", null ],
