@@ -3,7 +3,9 @@ var structflecs_1_1entity =
     [ "entity", "structflecs_1_1entity.html#ac475621a5fb9513885c12474ba7ffd67", null ],
     [ "entity", "structflecs_1_1entity.html#a8baaadf7cffb365c70109d5b00e54fea", null ],
     [ "entity", "structflecs_1_1entity.html#a5507fae8c3f326e957f468372b63b322", null ],
+    [ "entity", "structflecs_1_1entity.html#ac343dbb0c6a3cd44bd97863127a1c2a0", null ],
     [ "entity", "structflecs_1_1entity.html#a9d2361efe2ea358b3bd0728408ced507", null ],
+    [ "child", "structflecs_1_1entity.html#af6ff23d1598489b6213284a29dcd2a9a", null ],
     [ "clear", "structflecs_1_1entity.html#a3a115a6cbd08c6de08e0ecfe8608ccbb", null ],
     [ "destruct", "structflecs_1_1entity.html#a05c1af95015764fc68aa790d274f4462", null ],
     [ "ensure", "structflecs_1_1entity.html#a8fca9021f1846e165eba581adaee64ba", null ],
@@ -16,10 +18,12 @@ var structflecs_1_1entity =
     [ "from_json", "group__cpp__addons__json.html#ga47edfb42247b4e13c3c1c07658be724e", null ],
     [ "get_ref", "structflecs_1_1entity.html#a0cedfc7447654b086c0e6a9d6086515f", null ],
     [ "get_ref", "structflecs_1_1entity.html#aee5caacc56de16ca8198f4bafb6bc90c", null ],
+    [ "get_ref_w_id", "structflecs_1_1entity.html#a45bcfbaa8eea7b8cfeaea9921367890f", null ],
     [ "modified", "structflecs_1_1entity.html#a8cb796e5781775753b5ca8fd9d85b59e", null ],
     [ "modified", "structflecs_1_1entity.html#a1d7203975cf6644f81ca20b911dcb12c", null ],
     [ "modified", "structflecs_1_1entity.html#a34ed2767da35c164134b21f4d4a083b4", null ],
     [ "modified", "structflecs_1_1entity.html#a46b645e7cdfe073077b392231e231f10", null ],
     [ "modified", "structflecs_1_1entity.html#a0e494b2a380e94acb8a15e10eb031170", null ],
+    [ "set_child_order", "structflecs_1_1entity.html#ad552d436290984e56b5327afc33c3833", null ],
     [ "view", "structflecs_1_1entity.html#acc0abe24401b9c3fb54187258a7edb64", null ]
 ];
\ No newline at end of file
